texttable: Python module for creating simple ASCII tables
=========================================================

Description
-----------

Python module for creating simple ASCII tables

License
-------

MIT License (MIT)


Upstream Contact
----------------

https://github.com/foutaise/texttable/

Dependencies
------------

-  python


Special Update/Build Instructions
---------------------------------
